@@ -9,6 +9,7 @@ from jinja2 import Environment, FileSystemLoader
 
 #from . import echo
 import echo
+from md import HighlightExtension
 
 
 class Template(object):
@@ -127,7 +128,8 @@ class Post(object):
         # http://packages.python.org/Markdown/extensions/index.html
         return markdown.markdown(
             text, 
-            extensions=['fenced_code', 'codehilite(guess_lang=False)', 'tables', 'footnotes', 'nl2br']
+            #extensions=['fenced_code', 'codehilite(guess_lang=False)', 'tables', 'footnotes', 'nl2br']
+            extensions=[HighlightExtension(), 'tables', 'footnotes', 'nl2br']
         )
 
     def __str__(self):
